@@ -8,3 +8,7 @@ test_that("rounding time works", {
 test_that("non-integer minutes fail", {
   expect_error(roundTime(Sys.time, 0.5))
 })
+
+test_that("hms works", {
+  expect_equal(strftime(roundTime(hms::as_hms("09:00:01"), minutes = 1), format = "%T"), "09:00:00")
+})
